Welcome to ipoly's documentation!
=================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   source/modules
   readme
   license.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
